@@ -258,7 +258,7 @@ Here's a verbatim copy of C<%default>, with some commentary about values.
       root_dir       => '.',         # dir for wrt repository
       entry_dir      => 'archives',  # dir for entry files
       publish_dir    => 'public',    # dir to publish site to
-      url_root       => "$0?",       # root URL for building links
+      url_root       => "/",       # root URL for building links
       image_url_root => '',          # same for images
       template_dir   => 'templates', # dir for template files
       template       => 'default',   # template to use
@@ -301,7 +301,7 @@ my %default = (
   root_dir       => '.',         # dir for wrt repository
   entry_dir      => 'archives',  # dir for entry files
   publish_dir    => 'public',    # dir to publish site to
-  url_root       => "$0?",       # root URL for building links
+  url_root       => "/",         # root URL for building links
   image_url_root => '',          # same for images
   template_dir   => 'templates', # dir for template files
   template       => 'default',   # template to use
@@ -905,7 +905,7 @@ sub entry_topic_list {
 
   return join ', ', map {
     s/^tag-(.*)[.]prop$/$1/;
-    a($_, { href => '/topics/' . $_ })
+    a($_, { href => $self->url_root . 'topics/' . $_ })
   } @tag_files;
 }
 
